@@ -21,16 +21,18 @@ package org.apache.maven.shared.invoker;
 
 import java.io.File;
 import java.io.InputStream;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
+import org.apache.maven.shared.utils.StringUtils;
+
 /**
  * Specifies the parameters used to control a Maven invocation.
- * 
- * @version $Id: DefaultInvocationRequest.java 1752078 2016-07-10 11:25:08Z khmarbaise $
+ *
  */
 public class DefaultInvocationRequest
     implements InvocationRequest
@@ -104,170 +106,262 @@ public class DefaultInvocationRequest
 
     private String builderId;
 
+    private int timeoutInSeconds = NO_TIMEOUT;
+
+    private boolean quiet;
+
+    private File mavenHome;
+
+    private File mavenExecutable;
+
+    private boolean noTransferProgress;
+
+    private List<String> args = new ArrayList<>();
+
+    /**
+     * <p>getBaseDirectory.</p>
+     *
+     * @return a {@link java.io.File} object.
+     */
     public File getBaseDirectory()
     {
         return basedir;
     }
 
+    /** {@inheritDoc} */
     public File getBaseDirectory( File defaultDirectory )
     {
         return basedir == null ? defaultDirectory : basedir;
     }
 
+    /** {@inheritDoc} */
     public InvocationOutputHandler getErrorHandler( InvocationOutputHandler defaultHandler )
     {
         return errorHandler == null ? defaultHandler : errorHandler;
     }
 
+    /**
+     * <p>getReactorFailureBehavior.</p>
+     *
+     * @return a ReactorFailureBehavior object.
+     */
     public ReactorFailureBehavior getReactorFailureBehavior()
     {
         return failureBehavior;
     }
 
+    /**
+     * <p>Getter for the field <code>goals</code>.</p>
+     *
+     * @return a {@link java.util.List} object.
+     */
     public List<String> getGoals()
     {
         return goals;
     }
 
+    /** {@inheritDoc} */
     public InputStream getInputStream( InputStream defaultStream )
     {
         return inputStream == null ? defaultStream : inputStream;
     }
 
+    /** {@inheritDoc} */
     public File getLocalRepositoryDirectory( File defaultDirectory )
     {
         return localRepository == null ? defaultDirectory : localRepository;
     }
 
+    /** {@inheritDoc} */
     public InvocationOutputHandler getOutputHandler( InvocationOutputHandler defaultHandler )
     {
         return outputHandler == null ? defaultHandler : outputHandler;
     }
 
+    /**
+     * <p>Getter for the field <code>pomFile</code>.</p>
+     *
+     * @return a {@link java.io.File} object.
+     */
     public File getPomFile()
     {
         return pomFile;
     }
 
+    /**
+     * <p>Getter for the field <code>properties</code>.</p>
+     *
+     * @return a {@link java.util.Properties} object.
+     */
     public Properties getProperties()
     {
         return properties;
     }
 
+    /**
+     * <p>isDebug.</p>
+     *
+     * @return a boolean.
+     */
     public boolean isDebug()
     {
         return debug;
     }
 
+    /**
+     * <p>isBatchMode.</p>
+     *
+     * @return a boolean.
+     */
     public boolean isBatchMode()
     {
         return interactive;
     }
 
+    /**
+     * <p>isOffline.</p>
+     *
+     * @return a boolean.
+     */
     public boolean isOffline()
     {
         return offline;
     }
 
+    /**
+     * <p>isShowErrors.</p>
+     *
+     * @return a boolean.
+     */
     public boolean isShowErrors()
     {
         return showErrors;
     }
 
+    /**
+     * <p>isUpdateSnapshots.</p>
+     *
+     * @return a boolean.
+     */
     public boolean isUpdateSnapshots()
     {
         return updateSnapshots;
     }
 
+    /**
+     * <p>isRecursive.</p>
+     *
+     * @return a boolean.
+     */
     public boolean isRecursive()
     {
         return recursive;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setRecursive( boolean recursive )
     {
         this.recursive = recursive;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setBaseDirectory( File basedir )
     {
         this.basedir = basedir;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setDebug( boolean debug )
     {
         this.debug = debug;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setErrorHandler( InvocationOutputHandler errorHandler )
     {
         this.errorHandler = errorHandler;
         return this;
     }
 
+    /**
+     * <p>setReactorFailureBehavior.</p>
+     *
+     * @param failureBehavior a ReactorFailureBehavior object.
+     * @return a {@link org.apache.maven.shared.invoker.InvocationRequest} object.
+     */
     public InvocationRequest setReactorFailureBehavior( ReactorFailureBehavior failureBehavior )
     {
         this.failureBehavior = failureBehavior;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setGoals( List<String> goals )
     {
         this.goals = goals;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setInputStream( InputStream inputStream )
     {
         this.inputStream = inputStream;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setBatchMode( boolean interactive )
     {
         this.interactive = interactive;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setLocalRepositoryDirectory( File localRepository )
     {
         this.localRepository = localRepository;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setOffline( boolean offline )
     {
         this.offline = offline;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setOutputHandler( InvocationOutputHandler outputHandler )
     {
         this.outputHandler = outputHandler;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setPomFile( File pomFile )
     {
         this.pomFile = pomFile;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setProperties( Properties properties )
     {
         this.properties = properties;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setShowErrors( boolean showErrors )
     {
         this.showErrors = showErrors;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setUpdateSnapshots( boolean updateSnapshots )
     {
         this.updateSnapshots = updateSnapshots;
@@ -275,27 +369,34 @@ public class DefaultInvocationRequest
     }
 
     /**
-     * @see MavenCommandLineBuilder#setShellEnvironment(InvocationRequest, org.codehaus.plexus.util.cli.Commandline)
+     * <p>isShellEnvironmentInherited.</p>
+     *
+     * @see MavenCommandLineBuilder#setShellEnvironment(InvocationRequest, Commandline)
+     * @return a boolean.
      */
     public boolean isShellEnvironmentInherited()
     {
         return shellEnvironmentInherited;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setShellEnvironmentInherited( boolean shellEnvironmentInherited )
     {
         this.shellEnvironmentInherited = shellEnvironmentInherited;
         return this;
     }
 
+    /**
+     * <p>Getter for the field <code>javaHome</code>.</p>
+     *
+     * @return a {@link java.io.File} object.
+     */
     public File getJavaHome()
     {
         return javaHome;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setJavaHome( File javaHome )
     {
         this.javaHome = javaHome;
@@ -304,15 +405,15 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a {@link java.io.File} object.
      */
     public File getUserSettingsFile()
     {
         return userSettings;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setUserSettingsFile( File userSettings )
     {
         this.userSettings = userSettings;
@@ -321,15 +422,15 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a {@link java.io.File} object.
      */
     public File getGlobalSettingsFile()
     {
         return globalSettings;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setGlobalSettingsFile( File globalSettings )
     {
         this.globalSettings = globalSettings;
@@ -338,15 +439,15 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a {@link java.io.File} object.
      */
     public File getToolchainsFile()
     {
         return toolchains;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setToolchainsFile( File toolchains )
     {
         this.toolchains = toolchains;
@@ -355,15 +456,15 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a {@link java.io.File} object.
      */
     public File getGlobalToolchainsFile()
     {
         return globalToolchains;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setGlobalToolchainsFile( File toolchains )
     {
         this.globalToolchains = toolchains;
@@ -373,6 +474,8 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a CheckSumPolicy object.
      */
     public CheckSumPolicy getGlobalChecksumPolicy()
     {
@@ -381,6 +484,9 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @param globalChecksumPolicy a CheckSumPolicy object.
+     * @return a {@link org.apache.maven.shared.invoker.InvocationRequest} object.
      */
     public InvocationRequest setGlobalChecksumPolicy( CheckSumPolicy globalChecksumPolicy )
     {
@@ -390,15 +496,31 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a {@link java.lang.String} object.
      */
     public String getPomFileName()
     {
         return pomFilename;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+
+    @Override
+    public InvocationRequest addArg( String arg )
+    {
+        if ( StringUtils.isNotBlank( arg ) )
+        {
+            args.add( arg );
+        }
+        return this;
+    }
+
+    public List<String> getArgs()
+    {
+        return args;
+    }
+
+    /** {@inheritDoc} */
     public InvocationRequest setPomFileName( String pomFilename )
     {
         this.pomFilename = pomFilename;
@@ -407,15 +529,15 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a {@link java.util.List} object.
      */
     public List<String> getProfiles()
     {
         return profiles;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setProfiles( List<String> profiles )
     {
         this.profiles = profiles;
@@ -424,41 +546,53 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a boolean.
      */
     public boolean isNonPluginUpdates()
     {
         return nonPluginUpdates;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setNonPluginUpdates( boolean nonPluginUpdates )
     {
         this.nonPluginUpdates = nonPluginUpdates;
         return this;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest addShellEnvironment( String name, String value )
     {
         if ( this.shellEnvironments == null )
         {
-            this.shellEnvironments = new HashMap<String, String>();
+            this.shellEnvironments = new HashMap<>();
         }
         this.shellEnvironments.put( name, value );
         return this;
     }
 
+    /**
+     * <p>Getter for the field <code>shellEnvironments</code>.</p>
+     *
+     * @return a {@link java.util.Map} object.
+     */
     public Map<String, String> getShellEnvironments()
     {
         return shellEnvironments == null ? Collections.<String, String>emptyMap() : shellEnvironments;
     }
 
+    /**
+     * <p>Getter for the field <code>mavenOpts</code>.</p>
+     *
+     * @return a {@link java.lang.String} object.
+     */
     public String getMavenOpts()
     {
         return mavenOpts;
     }
 
+    /** {@inheritDoc} */
     public InvocationRequest setMavenOpts( String mavenOpts )
     {
         this.mavenOpts = mavenOpts;
@@ -466,16 +600,17 @@ public class DefaultInvocationRequest
     }
 
     /**
+     * <p>isShowVersion.</p>
+     *
      * @see org.apache.maven.shared.invoker.InvocationRequest#isShowVersion()
+     * @return a boolean.
      */
     public boolean isShowVersion()
     {
         return this.showVersion;
     }
 
-    /**
-     * @see org.apache.maven.shared.invoker.InvocationRequest#setShowVersion(boolean)
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setShowVersion( boolean showVersion )
     {
         this.showVersion = showVersion;
@@ -484,15 +619,15 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a {@link java.lang.String} object.
      */
     public String getThreads()
     {
         return threads;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setThreads( String threads )
     {
         this.threads = threads;
@@ -501,15 +636,15 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a {@link java.util.List} object.
      */
     public List<String> getProjects()
     {
         return projects;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setProjects( List<String> projects )
     {
         this.projects = projects;
@@ -518,15 +653,15 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a boolean.
      */
     public boolean isAlsoMake()
     {
         return alsoMake;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setAlsoMake( boolean alsoMake )
     {
         this.alsoMake = alsoMake;
@@ -535,15 +670,15 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a boolean.
      */
     public boolean isAlsoMakeDependents()
     {
         return alsoMakeDependents;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setAlsoMakeDependents( boolean alsoMakeDependents )
     {
         this.alsoMakeDependents = alsoMakeDependents;
@@ -552,24 +687,22 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a {@link java.lang.String} object.
      */
     public String getResumeFrom()
     {
         return resumeFrom;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setResumeFrom( String resumeFrom )
     {
         this.resumeFrom = resumeFrom;
         return this;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    /** {@inheritDoc} */
     public InvocationRequest setBuilder( String id )
     {
         this.builderId = id;
@@ -578,10 +711,95 @@ public class DefaultInvocationRequest
 
     /**
      * {@inheritDoc}
+     *
+     * @return a {@link java.lang.String} object.
      */
     public String getBuilder()
     {
         return this.builderId;
     }
 
+
+    /** {@inheritDoc} */
+    @Override
+    public int getTimeoutInSeconds()
+    {
+        return timeoutInSeconds;
+    }
+
+    /** {@inheritDoc} */
+    @Override
+    public void setTimeoutInSeconds( int timeoutInSeconds )
+    {
+        this.timeoutInSeconds = timeoutInSeconds;
+    }
+
+    /**
+     * {@inheritDoc}
+     *
+     * @return a boolean.
+     * @since 3.1.0
+     */
+    public boolean isQuiet()
+    {
+        return quiet;
+    }
+
+    /** {@inheritDoc} */
+    public InvocationRequest setQuiet( boolean quiet )
+    {
+        this.quiet = quiet;
+        return this;
+    }
+
+    @Override
+    public boolean isNoTransferProgress()
+    {
+        return noTransferProgress;
+    }
+
+    @Override
+    public InvocationRequest setNoTransferProgress( boolean noTransferProgress )
+    {
+        this.noTransferProgress = noTransferProgress;
+        return this;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public File getMavenHome()
+    {
+        return mavenHome;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public InvocationRequest setMavenHome( File mavenHome )
+    {
+        this.mavenHome = mavenHome;
+        return this;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public File getMavenExecutable()
+    {
+        return mavenExecutable;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public InvocationRequest setMavenExecutable( File mavenExecutable )
+    {
+        this.mavenExecutable = mavenExecutable;
+        return this;
+    }
 }
